@@ -61,9 +61,10 @@ MQTT.set_socket(socket, eth)
 # Set up a MiniMQTT Client
 # NOTE: We'll need to connect insecurely for ethernet configurations.
 mqtt_client = MQTT.MQTT(
-    broker="http://io.adafruit.com",
+    broker="io.adafruit.com",
     username=secrets["aio_username"],
     password=secrets["aio_key"],
+    is_ssl=False,
 )
 
 # Setup the callback methods above
